/*----------------------------------------------------------------------------------*/
**	Code to replicate the analysis in Berry and Gersen QJPS Article				
/*----------------------------------------------------------------------------------*/

* Change the directory below to reflect the folder where you have placed the data files


/*----------------------------------------------------------------------------------*/
***	Table 1: Summary Statistics

use salary_data.dta, clear

bysort COCDS: gen obsno = _n

foreach var of varlist avg_salary_cpi avg_density avg_cnty_wage avg_ir65y avg_irownh avg_irfmwk avg_rfle avg_n_totstu {
	ttest `var' if obsno==1, by(even) unequal
	}

/* See additional notes below regarding the salary data set */
	
/*----------------------------------------------------------------------------------*/
*** Use voting data for tables 2 and 3. Prepare the data.
use voting_data.dta, clear

keep if month==11 /* Use November elections only */

* Specify control variables
global ctrl = "ilnpop irbpop iripop irapop iropop irhpop ir65y ilnavhi irownh irfmwk"
* Note: irwpop and ir1864y are excluded as baseline variables.


xtset group date
	
***	Table 2: School Board Turnout Summary

tabstat ivrate, by(year) stat(median count)
tabstat ivrate, by(odd_yr) stat(median count)


***	Table 3: School Board Turnout Regressions

reg ivrate odd_yr $ctrl, cluster(group)
	
reg ivrate d_pres d_gov d_sen $ctrl, cluster(group)
	
xtreg ivrate odd_yr $ctrl, fe cluster(group)
	
xtreg ivrate d_pres d_gov d_sen $ctrl, fe  cluster(group)
	

/*----------------------------------------------------------------------------------*/
*** Use salary data for Tables 4-7. Prepare the data	

use salary_data.dta, clear

* Notes re salary data: The data set contains annual district-level data on teacher salaries. 
* We use one observation per district reflecting the average value across all years (see paper for details).
* Variable names prefixed by avg_* denote the averages. Other variables contain annual data.
* The analyses reported in the paper do no change importantly when using annual vs. average values.
* We kept the annual data in the data set in case others may want to use it.
* Variables prefixed by ln_* denote natural log transformations

* Define control variables
global ctrl = "avg_ir65y avg_irownh avg_irfmwk"	/* Vars from Census */
global sdctrl = "avg_rfle ln_avg_totstu"		/* Vars from CA Dept of Ed */

* Drop 197 districts for which we could not match a 1987 salary
drop if SALARY_87==.

* Drop 12 districts that change election timing after 1999
drop if tru_change==1

* Pick one obervation from each district (since using average rather than annual data)
bysort COCDS: gen obsno = _n

***	Table 4: Salary Regressions

xi: reg ln_avg_salary_cpi even i.TYPE if obsno==1, robust

xi: reg ln_avg_salary_cpi even $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, robust

xi: reg ln_avg_salary_cpi even ln_SALARY87 $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, robust


***	Table 5: Diff-in-Diff Table

tabstat avg_salary_cpi SALARY_87 if e(sample), by(even)
	
/* Note: SALARY_87 can be multiplied by 1.9 to convert to 2008 dollars, as reported in the paper */
	
	
***	Table 6: Matching

/* Note: you may need to install these user-written commands before running Table 6 code: nnmatch, pscore, attk, dr. */

xi: nnmatch ln_avg_salary_cpi even $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, tc(ate) m(3) biasadj(bias)
	
xi: nnmatch ln_avg_salary_cpi even ln_SALARY87 $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, tc(ate) m(3) biasadj(bias) 
	
xi: pscore even $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, pscore(propscore1) comsup numblo(3)
xi: attk ln_avg_salary_cpi even $ctrl $sdctrl ln_cnty_wage ln_density i.TYPE if obsno==1, boot pscore(propscore1) comsup
	
xi: pscore even ln_SALARY87 $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, pscore(propscore2) comsup numblo(3)
xi: attk ln_avg_salary_cpi even ln_SALARY87 $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, boot pscore(propscore2) comsup
	
xi: dr ln_avg_salary_cpi even $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1 
	
xi: dr ln_avg_salary_cpi even ln_SALARY87 $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1 


***	Table 7: IV

xi: ivreg2 ln_avg_salary_cpi (even=ln_cog_off_county) ln_SALARY87 $ctrl $sdctrl ln_avg_cnty_wage ln_avg_density i.TYPE if obsno==1, first endog(even) robust


/*----------------------------------------------------------------------------------*/
***	Table 8: Test Scores

use test_data.dta, clear

* Normalize test scores to annual percentile ranks
bysort year STYPE: egen rank_API_b = rank(API_b)
bysort year STYPE: egen num_rank = count(API_b)
gen API_pct_rank = rank_API_b/num_rank
replace API_pct_rank = API_pct_rank*100


xi: reg API_pct even if ENROLL>1, cluster(D) 
	
xi: reg API_pct even MEALS sci PCT_AA ln_enroll if ENROLL>1, cluster(D) 

xtreg API_pct even MEALS sci PCT_AA ln_enroll if changer==1 & ENROLL>1, fe i(id_api) cluster(D)


